@@ -9,4 +9,4 @@ from .compat import text_
 
 class JsonBodyProperty(SimpleLazyObject):
     def __init__(self, request):
-        super(JsonBodyProperty, self).__init__(lambda: json.loads(text_(request.body, request.encoding)))
+        super(JsonBodyProperty, self).__init__(lambda: json.loads(text_(request.read(), request.encoding)))
